==> evolution-data-server_2.26.1.orig.tar.gz: evolution-data-server-2.26.1/camel/providers/imap/camel-imap-search.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* camel-imap-search.h: IMAP folder search */

/*
 *  Authors:
 *    Dan Winship <danw@ximian.com>
 *
 *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef _CAMEL_IMAP_SEARCH_H
#define _CAMEL_IMAP_SEARCH_H

#include <camel/camel-folder-search.h>
#include <camel/camel-list-utils.h>
#include <camel/camel-data-cache.h>

#define CAMEL_IMAP_SEARCH_TYPE         (camel_imap_search_get_type ())
#define CAMEL_IMAP_SEARCH(obj)         CAMEL_CHECK_CAST (obj, camel_imap_search_get_type (), CamelImapSearch)
#define CAMEL_IMAP_SEARCH_CLASS(klass) CAMEL_CHECK_CLASS_CAST (klass, camel_imap_search_get_type (), CamelImapSearchClass)
#define CAMEL_IS_IMAP_SEARCH(obj)      CAMEL_CHECK_TYPE (obj, camel_imap_search_get_type ())

G_BEGIN_DECLS

typedef struct _CamelImapSearchClass CamelImapSearchClass;

struct _CamelImapSearch {
	CamelFolderSearch parent;

	guint32 lastuid;	/* current 'last uid' for the folder */
	guint32 validity;	/* validity of the current folder */

	CamelDataCache *cache;	/* disk-cache for searches */

	/* cache of body search matches */
	unsigned int matches_count;
	CamelDList matches;
	GHashTable *matches_hash;
};

struct _CamelImapSearchClass {
	CamelFolderSearchClass parent_class;

};

CamelType              camel_imap_search_get_type (void);
CamelFolderSearch *camel_imap_search_new      (const char *cachedir);

G_END_DECLS

#endif /* ! _CAMEL_IMAP_SEARCH_H */

==> evolution-data-server_2.30.3.orig.tar.gz: evolution-data-server-2.30.3/camel/providers/imap/camel-imap-search.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* camel-imap-search.h: IMAP folder search */

/*
 *  Authors:
 *    Dan Winship <danw@ximian.com>
 *
 *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef _CAMEL_IMAP_SEARCH_H
#define _CAMEL_IMAP_SEARCH_H

#include <camel/camel-folder-search.h>
#include <camel/camel-list-utils.h>
#include <camel/camel-data-cache.h>

#define CAMEL_IMAP_SEARCH_TYPE         (camel_imap_search_get_type ())
#define CAMEL_IMAP_SEARCH(obj)         CAMEL_CHECK_CAST (obj, camel_imap_search_get_type (), CamelImapSearch)
#define CAMEL_IMAP_SEARCH_CLASS(klass) CAMEL_CHECK_CLASS_CAST (klass, camel_imap_search_get_type (), CamelImapSearchClass)
#define CAMEL_IS_IMAP_SEARCH(obj)      CAMEL_CHECK_TYPE (obj, camel_imap_search_get_type ())

G_BEGIN_DECLS

typedef struct _CamelImapSearchClass CamelImapSearchClass;

struct _CamelImapSearch {
	CamelFolderSearch parent;

	guint32 lastuid;	/* current 'last uid' for the folder */
	guint32 validity;	/* validity of the current folder */

	CamelDataCache *cache;	/* disk-cache for searches */

	/* cache of body search matches */
	guint matches_count;
	CamelDList matches;
	GHashTable *matches_hash;
};

struct _CamelImapSearchClass {
	CamelFolderSearchClass parent_class;

};

CamelType              camel_imap_search_get_type (void);
CamelFolderSearch *camel_imap_search_new      (const gchar *cachedir);

G_END_DECLS

#endif /* _CAMEL_IMAP_SEARCH_H */
